@@ -1,5 +1,35 @@
-### PMML: Predictive Modelling Markup Language
-##
+# PMML: Predictive Modelling Markup Language
+#
+# Part of the Rattle package for Data Mining
+#
+# Time-stamp: <2008-06-22 15:53:09 Graham Williams>
+#
+# Copyright (c) 2008 Togaware Pty Ltd
+#
+# This files is part of the Rattle suite for Data Mining in R.
+#
+# Rattle is free software: you can redistribute it and/or modify it
+# under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# Rattle is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Rattle. If not, see <http://www.gnu.org/licenses/>.
+#
+# ARules Module
+#
+# Implements a PMML exporter for arules objects (Association Rules)
+#
+# Author: 
+# E-mail: 
+# Date: 
+#
+# Conform to PMML 3.2 Graham Williams 080622
 
 markup <- function(x)
   gsub("<", "&lt;", gsub(">", "&gt;", gsub("&", "&amp;", x)))
@@ -14,16 +44,17 @@ pmml.rules <- function(model,
   #if (!inherits(model, "rules")) stop("Not a legitimate arules rules object")
   #require(XML, quietly=TRUE)
   #require(arules, quietly=TRUE)
-
   
-  ## PMML
-  pmml <- pmmlRootNode()
+  # PMML
+
+  pmml <- pmmlRootNode("3.2")
+
+  # PMML -> Header
 
-  ## PMML -> Header
-  if (is.null(copyright)) copyright <- ""
   pmml <- append.XMLNode(pmml, pmmlHeader(description, copyright, app.name))
 
-  ## PMML -> DataDictionary
+  # PMML -> DataDictionary
+
   data.dictionary <- xmlNode("DataDictionary", attrs=c(numberOfFields = 2L))
   data.dictionary <- append.xmlNode(data.dictionary, list(
       xmlNode("DataField", attrs=c(name="transaction",
@@ -34,11 +65,13 @@ pmml.rules <- function(model,
 
   pmml <- append.XMLNode(pmml, data.dictionary)
 
-  ## association rule model
+  # Association rule model
+
   quality <- quality(model)
   is <- c(lhs(model),rhs(model))
 
-  ## fixme: why does the S4 dispatch not work?
+  # fixme: why does the S4 dispatch not work?
+
   is.unique <- getMethod("unique", "itemMatrix")(is)
 
   association.model <- xmlNode("AssociationModel", 
@@ -124,7 +157,7 @@ pmml.itemsets <- function(model,
   pmml <- pmmlRootNode()
 
   ## PMML -> Header
-  if (is.null(copyright)) copyright <- ""
+
   pmml <- append.XMLNode(pmml, pmmlHeader(description, copyright, app.name))
 
   ## PMML -> DataDictionary
